pub unsafe extern "C" fn thinlto_codegen_add_cross_referenced_symbol(
cg: *mut LLVMOpaqueThinLTOCodeGenerator,
name: *const i8,
length: i32,
)Expand description
Add a symbol to the list of global symbols that are cross-referenced between ThinLTO files.
Symbols listed can be discarded if every reference from a ThinLTO module to a symbol is optimized away, then the symbol can be discarded.