pub unsafe extern "C" fn thinlto_codegen_add_must_preserve_symbol(
cg: *mut LLVMOpaqueThinLTOCodeGenerator,
name: *const i8,
length: i32,
)Expand description
Add a symbol to the list of global symbols that must exist in the final generated code.
Functions not listed may be inlined in every usage and optimized away.