pub unsafe extern "C" fn thinlto_codegen_set_savetemps_dir(
cg: *mut LLVMOpaqueThinLTOCodeGenerator,
save_temps_dir: *const i8,
)Expand description
Set the path to a directory to use as temporary bitcode storage.
This is meant to make the bitcode files available for debugging.